# Circles!

This is an implementation of Circles which is a yet to be implemented graphical esolang created by [PythonshellDebugwindow](https://github.com/PythonshellDebugwindow).

I think this is a nice esolang so I'm gonna implement this.

# Circles?

* Make sure `pip` is up-to-date.
  ```
  python -m pip install pip --upgrade
  ```
* O
  ```
  python -m pip install circleso
  ```
* Interpret Circles programs with
  ```
  python -m circles path/to/program.png
  ```
* For more options and or thingies, do
  ```
  python -m circles --help
  ```
# Thoughts on standards

I don't think you really need to have standards since it's entirely possible to detect circles of any size with opencv
